#!/bin/sh
# Exercise the --sort=width option.

# Copyright (C) 2021-2022 Free Software Foundation, Inc.

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

. "${srcdir=.}/tests/init.sh"; path_prepend_ ./src
print_ver_ ls

mkdir subdir       || framework_failure_
touch subdir/aaaaa || framework_failure_
touch subdir/bbb   || framework_failure_
touch subdir/cccc  || framework_failure_
touch subdir/d     || framework_failure_
touch subdir/zz    || framework_failure_


ls --sort=width subdir > out || fail=1
cat <<\EOF > exp || framework_failure_
d
zz
bbb
cccc
aaaaa
EOF

compare exp out || fail=1

Exit $fail
